@@ -1,10 +1,10 @@
+import io
 import os
 from os.path import dirname, abspath, join as pjoin
 import tarfile
 from testpath import modified_env, assert_isfile
 from testpath.tempdir import TemporaryDirectory, TemporaryWorkingDirectory
 import pytest
-import toml
 import zipfile
 import sys
 import json
@@ -14,6 +14,7 @@ try:
 except ImportError:
     from unittest.mock import Mock
 
+from pep517.compat import toml_load
 from pep517.wrappers import Pep517HookCaller, default_subprocess_runner
 from pep517.wrappers import UnsupportedOperation, BackendUnavailable
 
@@ -28,8 +29,8 @@ BUILDSYS_PKGS = pjoin(SAMPLES_DIR, 'buildsys_pkgs')
 
 def get_hooks(pkg, **kwargs):
     source_dir = pjoin(SAMPLES_DIR, pkg)
-    with open(pjoin(source_dir, 'pyproject.toml')) as f:
-        data = toml.load(f)
+    with io.open(pjoin(source_dir, 'pyproject.toml'), encoding="utf-8") as f:
+        data = toml_load(f)
     return Pep517HookCaller(
         source_dir, data['build-system']['build-backend'], **kwargs
     )
@@ -49,6 +50,13 @@ def test_get_requires_for_build_wheel():
     assert res == ['wheelwright']
 
 
+def test_get_requires_for_build_editable():
+    hooks = get_hooks('pkg1')
+    with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
+        res = hooks.get_requires_for_build_editable({})
+    assert res == ['wheelwright', 'editables']
+
+
 def test_get_requires_for_build_sdist():
     hooks = get_hooks('pkg1')
     with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
@@ -65,6 +73,15 @@ def test_prepare_metadata_for_build_wheel():
         assert_isfile(pjoin(metadatadir, 'pkg1-0.5.dist-info', 'METADATA'))
 
 
+def test_prepare_metadata_for_build_editable():
+    hooks = get_hooks('pkg1')
+    with TemporaryDirectory() as metadatadir:
+        with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
+            hooks.prepare_metadata_for_build_editable(metadatadir, {})
+
+        assert_isfile(pjoin(metadatadir, 'pkg1-0.5.dist-info', 'METADATA'))
+
+
 def test_build_wheel():
     hooks = get_hooks('pkg1')
     with TemporaryDirectory() as builddir:
@@ -79,6 +96,20 @@ def test_build_wheel():
         assert zipfile.is_zipfile(whl_file)
 
 
+def test_build_editable():
+    hooks = get_hooks('pkg1')
+    with TemporaryDirectory() as builddir:
+        with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
+            whl_file = hooks.build_editable(builddir, {})
+
+        assert whl_file.endswith('.whl')
+        assert os.sep not in whl_file
+
+        whl_file = pjoin(builddir, whl_file)
+        assert_isfile(whl_file)
+        assert zipfile.is_zipfile(whl_file)
+
+
 def test_build_wheel_relpath():
     hooks = get_hooks('pkg1')
     with TemporaryWorkingDirectory() as builddir:
@@ -171,3 +202,12 @@ def test_issue_104():
         '__init__.py', '__init__.pyc', '_in_process.py', '_in_process.pyc',
         '__pycache__',
     }
+
+
+def test_setup_py():
+    hooks = get_hooks('setup-py')
+    with modified_env({'PYTHONPATH': BUILDSYS_PKGS}):
+        res = hooks.get_requires_for_build_wheel({})
+    # Some versions of setuptools list setuptools itself here
+    res = [x for x in res if x != 'setuptools']
+    assert res == ['wheel']
